(sessions)=

# Sessions

- Exist inside {ref}`Servers`
- Contain {ref}`Windows` (which contain {ref}`Panes`)
- Identified by `$`, e.g. `$313`

```{eval-rst}
.. autoclass:: libtmux.Session
    :members:
    :inherited-members:
    :private-members:
    :show-inheritance:
    :member-order: bysource
```
